@@ -1,5 +1,5 @@
 from crispy_forms.helper import FormHelper
-from crispy_forms.layout import Submit, Layout, Div, Fieldset, HTML
+from crispy_forms.layout import HTML, Div, Fieldset, Layout, Submit
 from django import forms
 from django.utils.translation import gettext_lazy as _
 
@@ -8,6 +8,7 @@ class AdminCrispyForm(forms.Form):
     """
     Base crispy form to be used in custom views within the django admin.
     """
+
     section_title = _('No title defined')
     button_label = _('Save')
 
@@ -25,10 +26,7 @@ class AdminCrispyForm(forms.Form):
         self.helper.add_input(Submit('submit', self.button_label, css_class="button btn-primary"))
         self.helper.layout = Layout(
             Div(
-                Div(
-                    HTML(f'<h2>{self.section_title}</h2>'),
-                    Fieldset(*fieldset_list),
-                    css_class='module aligned'
-                ), css_class='custom-form'
+                Div(HTML(f'<h2>{self.section_title}</h2>'), Fieldset(*fieldset_list), css_class='module aligned'),
+                css_class='custom-form',
             ),
         )
